FROM_ADDRESS_COL = "from_address"
TO_ADDRESS_COL = "to_address"
ADDRESS_COL = "address"
ZERO_ADDRESS = "to_address"
CONTRACT_ADDRESS_COL = "contract_address"
AMOUNT_PRICE_COL = "amount_precise"
SYMBOL_COL = "symbol"
AMOUNT_USD_COL = "amount_usd"
AMOUNT_COL = "amount"
TOKEN_PRICE_COL = "token_price"
BLOCK_NUM_COL = "block_number"
BLOCK_TIMESTAMP_COL = "block_timestamp"
DURATION_LABEL_COL = "duration"
FLIPSIDE_URL = "https://api-v2.flipsidecrypto.xyz"
DEFAULT_SOURCE_STORE = "./data/source_save/"
STORE_SIZE_CHECKPOINT = 41943040
DEFAULT_SF_KEY = "default"
TIMESERIES_SF_KEY = "timeseries_feature"
ADDRESS_SF_KEY = "address"
VECTOR_SF_KEY = "vector"
COSINE_SIM_SF_KEY = "cosine_sim"
OTHER_SF_KEY = "other"
MERGED_SF_KEY = "merged"
TOKEN_SF_KEY = "token"
TOP_ADDRESS_SF_KEY = "top_address"
EXCLUSION_SF_KEY = "exclusion"
TOKEN_PRICE_SF_KEY = "token_price"
PROFIT_LOSS_SF_KEY = "profit_loss"
DUPLICATED_SF_KEY = "duplicated"
SPARK_APP_NAME = "seshat"
PANDAS_MODE = "df"
PYSPARK_MODE = "spf"
DEFAULT_MODE = PANDAS_MODE
TRAIN_SF_KEY = "train"
TEST_SF_KEY = "test"
TOP_TOKEN_LIMIT = 20
